==> techne-0.1.tar.gz: techne-0.1/src/dissolve.c <==
/* Copyright (C) 2009 Papavasileiou Dimitris                             
 *                                                                      
 * This program is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or    
 * (at your option) any later version.                                  
 *                                                                      
 * This program is distributed in the hope that it will be useful,      
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
 * GNU General Public License for more details.                         
 *                                                                      
 * You should have received a copy of the GNU General Public License    
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <GL/glu.h>
#include "dissolve.h"

@implementation Dissolve

-(Dissolve *) init
{
    self = [super init];
    
    return self;
}

-(void) cleanup
{
    [super cleanup];

    if (self->delta < self->duration) {
	glMatrixMode (GL_PROJECTION);
	glPushMatrix();
	glLoadIdentity();
	glOrtho (0, 1, 0, 1, -1, 1);

	glMatrixMode (GL_MODELVIEW);
	glLoadIdentity();

	glUseProgramObjectARB (0);
	glDepthMask (GL_FALSE);
    
	glActiveTexture(GL_TEXTURE0);
	glEnable (GL_TEXTURE_2D);
	glBindTexture (GL_TEXTURE_2D, self->texture);
    
	glEnable (GL_BLEND);
	glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);

	glColor4f (1, 1, 1, 1 - self->delta / self->duration);

	glBegin (GL_QUADS);
	glTexCoord2f (0, 0);
	glVertex2f (0, 0);

	glTexCoord2f (1, 0);
	glVertex2f (1, 0);

	glTexCoord2f (1, 1);
	glVertex2f (1, 1);

	glTexCoord2f (0, 1);
	glVertex2f (0, 1);
	glEnd();
    
	glDisable (GL_BLEND);
	glDisable (GL_TEXTURE_2D);
	glDepthMask(GL_TRUE);

	glMatrixMode (GL_PROJECTION);
	glPopMatrix();
    }
}

@end

==> techne-0.2.2.tar.gz: techne-0.2.2/src/dissolve.c <==
/* Copyright (C) 2009 Papavasileiou Dimitris                             
 *                                                                      
 * This program is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or    
 * (at your option) any later version.                                  
 *                                                                      
 * This program is distributed in the hope that it will be useful,      
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
 * GNU General Public License for more details.                         
 *                                                                      
 * You should have received a copy of the GNU General Public License    
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <GL/glu.h>
#include "dissolve.h"

@implementation Dissolve

-(Dissolve *) init
{
    self = [super init];
    
    return self;
}

-(void) finish
{
    [super finish];

    if (self->progress > 0 && self->progress < 1) {
	glMatrixMode (GL_PROJECTION);
	glPushMatrix();
	glLoadIdentity();
	glOrtho (0, 1, 0, 1, -1, 1);

	glMatrixMode (GL_MODELVIEW);
	glPushMatrix();
	glLoadIdentity();

	glUseProgramObjectARB (0);
	glDepthMask (GL_FALSE);
    
	glActiveTexture(GL_TEXTURE0);
	glEnable (GL_TEXTURE_2D);
	glBindTexture (GL_TEXTURE_2D, self->texture);
    
	glEnable (GL_BLEND);
	glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);

	glColor4f (1, 1, 1, 1 - self->progress);

	glBegin (GL_QUADS);
	glTexCoord2f (0, 0);
	glVertex2f (0, 0);

	glTexCoord2f (1, 0);
	glVertex2f (1, 0);

	glTexCoord2f (1, 1);
	glVertex2f (1, 1);

	glTexCoord2f (0, 1);
	glVertex2f (0, 1);
	glEnd();
    
	glDisable (GL_BLEND);
	glDisable (GL_TEXTURE_2D);
	glDepthMask(GL_TRUE);

	glMatrixMode (GL_PROJECTION);
	glPopMatrix();

	glMatrixMode (GL_MODELVIEW);
	glPopMatrix();
    }
}

@end
